@@ -26,7 +26,8 @@ class PropertyMapper(object):
         self.format = (attr is None) and (cell.format or cell.format_func)
 
     def __call__(self, cell, obj, renderer):
-        value = getattr(obj, self.attr or cell.attr)
+        attr = self.attr or cell.attr
+        value = obj if attr is None else getattr(obj, attr)
         if self.format:
             value = self.cell.format_data(value)
         renderer.set_property(self.prop, value)
@@ -172,6 +173,7 @@ class Column(object):
     :param searchable: Whether this field is searchable
     :param search_key: The key used to search this column
     :param expander: Whether the expander should be shown before this column
+    :param resizable: Whether the user can resize the column
     :param cells: A list of Cell instances to display in this colum
     :param tooltip_attr: An attribute that will display the tooltip for this
                          column
@@ -186,7 +188,6 @@ class Column(object):
 
         #XXX: better error messages
         assert title or attr, "Columns need a title or an attribute to infer it"
-        assert attr or 'cells' in kwargs, 'Columns need a attribute or a set of cells'
 
         self.title = title or attr.capitalize()
         self.attr = attr
@@ -195,6 +196,7 @@ class Column(object):
         self.visible = kwargs.pop('visible', True)
         self.width = kwargs.pop('width', None)
         self.expander = kwargs.pop('expander', None)
+        self.resizable = kwargs.pop('resizable', None)
         self.sort_key = kwargs.pop('sort_key', None)
         self.sort_func = kwargs.pop('sort_func', cmp)
         # tooltips are per column, not per cell
@@ -216,6 +218,8 @@ class Column(object):
         col.props.visible = self.visible
         if self.expand is not None:
             col.props.expand = self.expand
+        if self.resizable is not None:
+            col.props.resizable = self.resizable
         if self.width is not None:
             col.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
             col.set_fixed_width(self.width)
@@ -272,10 +276,9 @@ class Column(object):
         return True
 
     def _default_sort_func(self, model, iter1, iter2, objectlist):
-        attr1 = getattr(objectlist._object_at_child_sort_iter(iter1),
-                        self.attr, None)
-        attr2 = getattr(objectlist._object_at_child_sort_iter(iter2),
-                        self.attr, None)
+        assert model is objectlist.model_filter  # the filtermodel gets sorted
+        attr1 = getattr(model[iter1][0], self.attr, None)
+        attr2 = getattr(model[iter2][0], self.attr, None)
         if self.sort_key:
             attr1 = self.sort_key(attr1)
             attr1 = self.sort_key(attr2)
@@ -820,8 +823,9 @@ class EditableCellMixin(object):
             self.connect('edited', self._on_edited)
 
     def _on_edited(self, cellrenderer, path, text):
-        obj = self.objectlist[path]
+        obj = self.objectlist._object_at_sort_path(path)
         #XXX: full converter
+        #XXX: breaks if attr is None
         value = self.cell.type(text)
         setattr(obj, self.cell.attr, value)
         self.objectlist.emit('item-changed', obj, self.cell.attr, value)
@@ -859,7 +863,7 @@ class CellRendererSpin(EditableCellMixin, gtk.CellRendererSpin):
 
 
     def _on_edited(self, cellrenderer, path, text):
-        obj = self.objectlist[path]
+        obj = self.objectlist._object_at_sort_path(path)
         #XXX: full converter
         value = self.cell.type(text)
         setattr(obj, self.cell.attr, value)
@@ -878,7 +882,7 @@ class CellRendererToggle(gtk.CellRendererToggle):
             self.connect('toggled', self._on_toggled)
 
     def _on_toggled(self, cellrenderer, path):
-        obj = self.objectlist._object_at_path(path)
+        obj = self.objectlist._object_at_sort_path(path)
         value = not getattr(obj, self.cell.attr)
         setattr(obj, self.cell.attr, value)
         self.objectlist.emit('item-changed', obj, self.cell.attr, value)
