@@ -194,6 +194,13 @@ def test_cell_format_string():
     cell = Cell('test', format='hoo %s')
     assert cell.format_data(1) == 'hoo 1'
 
+def test_cell_format_for_obj():
+    cell = Cell(None)
+    renderer = Mock()
+    cell.mappers[0].mappers[0](cell, 1, renderer)
+    assert renderer.set_property.call_args[0][1] == 1
+
+
 def test_default_type():
     cell = Cell('test')
     assert cell.mappers[0].mappers[0].prop == 'text'
